@@ -184,11 +184,7 @@ program SEQ
 
      do j=1,nz
         do i=2,nr
-           if(j/=1)then
-              taur(i,j)=nu(i,j)*(taur(i,j)-v0(i,j)/r(i))
-           else
-              taur(i,j)=-Cd*abs(v0(i,j))*v0(i,j)
-           end if
+           taur(i,j)=nu(i,j)*(taur(i,j)-v0(i,j)/r(i))
         end do
      end do
 
@@ -198,6 +194,10 @@ program SEQ
         end do
      end do
 
+     do i=1,nr
+        tauz(i,1)=Cd*abs(v0(i,1))*v0(i,1)
+     end do
+
 !-- ޤǤ, ϥƥ󥽥η׻λ.
 !-- ʹߤήեåη׻.
 
@@ -208,7 +208,7 @@ program SEQ
         end do
      end do
 
-     do j=1,nz
+     do j=2,nz
         call grad_1d( r, taur(:,j), dmomdz(:,j) )
         do i=1,nr
            mom(i,j)=mom(i,j)+dmomdz(i,j)
@@ -221,6 +221,7 @@ program SEQ
         end do
      end do
 
+!     mom=0.0
 !     do i=1,nr
 !        mom(i,1)=-Cd*abs(v0(i,1))*v0(i,1)
 !        call grad_1d( z, mom(i,:), dmomdz(i,:) )
