@@ -19,9 +19,13 @@ program fft_test
   character(1) :: flag
   integer, dimension(5) :: prim
   complex, allocatable, dimension(:,:) :: omegar, omegai, omeganr, omegani
+  character(20) :: foma, fomb
 
   flag=""
 
+  foma='(a13,1p,E14.5)'
+  fomb='(a18,1p,E14.5,a5)'
+
   write(*,*) "Input the data number (odd number)."
   read(*,*) n
 
@@ -83,8 +87,8 @@ program fft_test
 
   call max_val_1d( err, emax, err_max )
 
-  write(*,*) "-------------------------------"
-  write(*,*) "fft error is ", err_max
+  write(*,*) "-------------------------------------"
+  write(*,trim(foma)) "fft error is ", err_max
 
   call cpu_time( to1 )
 
@@ -110,13 +114,13 @@ program fft_test
 
   call max_val_1d( err, emax, err_max )
 
-  write(*,*) "fft error is ", err_max
-  write(*,*) "-------------------------------"
+  write(*,trim(foma)) "fft error is ", err_max
+  write(*,*) "-------------------------------------"
 
-  write(*,*) "-------------------------------"
-  write(*,*) "cpu time (rot) is ", ta2-ta1, "[s]."
-  write(*,*) "cpu time (fft) is ", tf2-tf1, "[s]."
-  write(*,*) "cpu time (dft) is ", to2-to1, "[s]."
-  write(*,*) "-------------------------------"
+  write(*,*) "-------------------------------------"
+  write(*,trim(fomb)) "cpu time (rot) is ", ta2-ta1, " [s]."
+  write(*,trim(fomb)) "cpu time (fft) is ", tf2-tf1, " [s]."
+  write(*,trim(fomb)) "cpu time (dft) is ", to2-to1, " [s]."
+  write(*,*) "-------------------------------------"
 
 end program
