@@ -13,7 +13,8 @@ end interface read_file_gtool3_header
 contains
 
 
-subroutine read_file( file_name, nx, ny, rec_num, var )  ! Ϸɤ߼롼
+subroutine read_file( file_name, nx, ny, rec_num, var, offset )
+  ! Ϸɤ߼롼
   ! ܥ롼Ǥ, 쥯ȥɤ߽Ф, 1 ѿΥХȿ 4 Х
   ! Ȳꤷɤ߽ФΤ, 4 ХȰʳΥեɤ߽ФȤ,
   ! Ϥ꥽եν񤭴ɬפȤʤ׽
@@ -23,18 +24,35 @@ subroutine read_file( file_name, nx, ny, rec_num, var )  ! Ϸɤ߼롼
   integer, intent(in) :: rec_num  ! ɤ߽ФǡΥ쥳ֹ
   character(*), intent(in) :: file_name  ! ɤ߽Фǡե̾
   real, intent(inout) :: var(nx,ny)  ! ɤ߽Фǡ
-  integer :: i, j  ! 
+  integer, intent(in), optional :: offset  ! ɤ߹߳ϰֻ
+                       ! ΥХȰ֤ޤǤϥåפ.
+                       ! 㤨, offset = 1 ʤ, Ƭ 4 byte Ф,
+                       !  4 byte ɤ߻Ϥ.
+                       ! ʤ, 줬ꤵ줿, rec_num ̵뤹.
+  integer :: i, j, k   ! 
 
-  open(unit=11, file=file_name, access='direct', recl=4*nx*ny, status='old')
-     read(11,rec=rec_num) ((var(i,j),i=1,nx),j=1,ny)
-  close(unit=11, status='keep')
+  if(present(offset))then
+     open(unit=11, file=file_name, access='direct', recl=4, status='old')
+        k=offset
+        do j=1,ny
+           do i=1,nx
+              k=k+1
+              read(11,rec=k) var(i,j)
+           end do
+        end do
+     close(unit=11, status='keep')
+  else
+     open(unit=11, file=file_name, access='direct', recl=4*nx*ny, status='old')
+        read(11,rec=rec_num) ((var(i,j),i=1,nx),j=1,ny)
+     close(unit=11, status='keep')
+  end if
 
 end subroutine read_file
 
 !-----------------------------------------------
 !-----------------------------------------------
 
-subroutine read_file_3d( file_name, nx, ny, nz, rec_num, var )
+subroutine read_file_3d( file_name, nx, ny, nz, rec_num, var, offset )
   ! read_file 3 .
   ! ܥ롼Ǥ, 쥯ȥɤ߽Ф, 1 ѿΥХȿ 4 Х
   ! Ȳꤷɤ߽ФΤ, 4 ХȰʳΥեɤ߽ФȤ,
@@ -46,13 +64,32 @@ subroutine read_file_3d( file_name, nx, ny, nz, rec_num, var )
   integer, intent(in) :: rec_num  ! ɤ߽Ф򳫻ϤǡΥ쥳ֹ
   character(*), intent(in) :: file_name  ! ɤ߽Фǡե̾
   real, intent(inout) :: var(nx,ny,nz)  ! ɤ߽Фǡ
-  integer :: i, j, k  ! 
+  integer, intent(in), optional :: offset  ! ɤ߹߳ϰֻ
+                       ! ΥХȰ֤ޤǤϥåפ.
+                       ! 㤨, offset = 1 ʤ, Ƭ 4 byte Ф,
+                       !  4 byte ɤ߻Ϥ.
+                       ! ʤ, 줬ꤵ줿, rec_num ̵뤹.
+  integer :: i, j, k, l  ! 
 
-  open(unit=11, file=file_name, access='direct', recl=4*nx*ny, status='old')
-     do k=1,nz
-        read(11,rec=rec_num+k-1) ((var(i,j,k),i=1,nx),j=1,ny)
-     end do
-  close(unit=11, status='keep')
+  if(present(offset))then
+     open(unit=11, file=file_name, access='direct', recl=4, status='old')
+        l=offset
+        do k=1,nz
+           do j=1,ny
+              do i=1,nx
+                 l=l+1
+                 read(11,rec=l) var(i,j,k)
+              end do
+           end do
+        end do
+     close(unit=11, status='keep')
+  else
+     open(unit=11, file=file_name, access='direct', recl=4*nx*ny, status='old')
+        do k=1,nz
+           read(11,rec=rec_num+k-1) ((var(i,j,k),i=1,nx),j=1,ny)
+        end do
+     close(unit=11, status='keep')
+  end if
 
 end subroutine read_file_3d
 
@@ -1205,7 +1242,9 @@ subroutine read_mgdsst( fname, sst )
   do k=1,ny
 !     read(12,formatt) (sstc(j,k),j=1,nx)
      do j=1,nx
-        if(sstc(j,k)=='888'.or.sstc(j,k)=='999')then
+        if(sstc(j,k)=='888')then
+           sst(j,ny-k+1)=263.15
+        else if(sstc(j,k)=='999')then
            sst(j,ny-k+1)=999.0
         else
            read(sstc(j,k),*) sst(j,ny-k+1)
