@@ -1,9 +1,9 @@
 file = Array[ 
-"alge_solv.f90",
 "algebra.f90",
 "assimilation.f90",
 "basis.f90",
 "derivation.f90",
+"ellip_slv.f90",
 "ffts.f90",
 "file_operate.f90",
 "geometry.f90",
@@ -26,11 +26,11 @@ file = Array[
 "typhoon_analy.f90" ]
 
 dir = Array[ 
-"Alge_Solv",
 "Algebra",
 "Assimilation",
 "Basis",
 "Derivation",
+"Ellip_Slv",
 "ffts",
 "file_operate",
 "Geometry",
