@@ -623,7 +623,7 @@ subroutine interpo_search_1d( x, point, i, undeff, stdopt )
   if(present(undeff))then
      just=undeff
   else
-     just=-2147483648
+     just=0
   end if
 
   if(present(stdopt))then
@@ -643,20 +643,10 @@ subroutine interpo_search_1d( x, point, i, undeff, stdopt )
         exit
      end if
 
-     if(present(undeff))then
-        if(x(j)/=real(undeff))then
-           if(x(j)<=point)then
-              i=j
-           else
-              exit
-           end if
-        end if
+     if(x(j)<=point)then
+        i=j
      else
-        if(x(j)<=point)then
-           i=j
-        else
-           exit
-        end if
+        exit
      end if
   end do
 
@@ -770,6 +760,7 @@ subroutine interpolation_1d( x, y, point, val, h, hp )
   fd=(xmax-xmin)/(tmax-tmin)
 
   val=xmin+dt*fd
+
 end subroutine interpolation_1d
 
 
@@ -852,6 +843,64 @@ end subroutine interpolation_3d
 !------------------------------------
 !------------------------------------
 
+subroutine interpo_undef_1d( x, undef, u )
+  ! ɸ x Ƥǡ u  undef ,
+  ! ܤͤäʻҤΥǡޤԤ.
+  ! ܳʻҤʤγޤϹԤʤ.
+  implicit none
+  real, intent(in) :: x(:)  ! ɸ
+  real, intent(in) :: undef  ! ̤
+  real, intent(inout) :: u(size(x))  ! ǡ
+
+  integer :: i, j, nx, counts, counte
+  integer :: ns(size(x)), ne(size(x))
+  real :: du
+
+  nx=size(x)
+  counts=0
+  counte=0
+
+  do i=2,nx-1
+     if(u(i)==undef)then
+        if(u(i-1)/=undef)then
+           counts=counts+1
+           ns(counts)=i
+        end if
+        if(u(i+1)/=undef)then
+           counte=counte+1
+           ne(counte)=i
+        end if
+     end if
+  end do
+
+  if(counts>1.and.counte>1)then
+     do i=2,counts
+        if(ns(i-1)>ne(i-1))then
+           du=(u(ne(i)+1)-u(ns(i-1)-1))/(x(ne(i)+1)-x(ns(i-1)-1))
+           do j=ns(i-1),ne(i)
+              u(j)=u(j-1)+du*(x(j)-x(j-1))
+           end do
+        else
+           du=(u(ne(i-1)+1)-u(ns(i-1)-1))/(x(ne(i-1)+1)-x(ns(i-1)-1))
+           do j=ns(i-1),ne(i-1)
+              u(j)=u(j-1)+du*(x(j)-x(j-1))
+           end do
+        end if
+     end do
+  else if(counts==1.and.counte==1)then
+     if(ns(1)<ne(1))then
+        du=(u(ne(1)+1)-u(ns(1)-1))/(x(ne(1)+1)-x(ns(1)-1))
+        do j=ns(1),ne(1)
+           u(j)=u(j-1)+du*(x(j)-x(j-1))
+        end do
+     end if
+  end if
+
+end subroutine interpo_undef_1d
+
+!------------------------------------
+!------------------------------------
+
 subroutine auto_interpolation_1d( x, r, u, v, undef, undefr, stdopt )
   ! ɸ x Ƥǡ u 
   ! ɸ r ǡ v ˼ưޤ.
@@ -860,7 +909,7 @@ subroutine auto_interpolation_1d( x, r, u, v, undef, undefr, stdopt )
   real, intent(in) :: r(:)  ! ޺ɸ
   real, intent(in) :: u(size(x))  ! ǡ
   real, intent(inout) :: v(size(r))  ! ޤǡ
-  integer, intent(in), optional :: undef  ! ̤
+  real, intent(in), optional :: undef  ! ̤
   real, intent(in), optional :: undefr  ! ΰǤ̤.
         !  undefr ʤ,  undefr 
   logical, intent(in), optional :: stdopt  ! õϰϤĤʤݤɸϤɽʤ褦ˤ.
@@ -875,7 +924,7 @@ subroutine auto_interpolation_1d( x, r, u, v, undef, undefr, stdopt )
   if(present(undef))then
      defun=undef
   else
-     defun=-2147483648
+     defun=-999.0
   end if
 
   if(present(undefr))then
@@ -891,9 +940,9 @@ subroutine auto_interpolation_1d( x, r, u, v, undef, undefr, stdopt )
   end if
 
   do i=1, nr
-     call interpo_search_1d( x, r(i), ir, int(defun), stdopt=stderr )
+     call interpo_search_1d( x, r(i), ir, undeff=0, stdopt=stderr )
 
-     if(ir/=int(defun))then
+     if(ir/=0)then
         if(ir<nx)then
            if(u(ir)/=rdefun.and.u(ir+1)/=rdefun)then
               call interpolation_1d( x(ir:ir+1), u(ir:ir+1), r(i), v(i) )
@@ -903,10 +952,10 @@ subroutine auto_interpolation_1d( x, r, u, v, undef, undefr, stdopt )
         else if(ir==nx.and.x(nx)==r(i))then
            v(i)=u(ir)
         else
-           v(i)=real(defun)
+           v(i)=defun
         end if
      else
-        v(i)=real(defun)
+        v(i)=defun
      end if
   end do
 
@@ -925,7 +974,7 @@ subroutine auto_interpolation_2d( x, y, r, q, u, v, undef, undefr, stdopt )
   real, intent(in) :: q(:)  ! ޺ɸ 2
   real, intent(in) :: u(size(x),size(y))  ! ǡ
   real, intent(inout) :: v(size(r),size(q))  ! ޤǡ
-  integer, intent(in), optional :: undef  ! ̤
+  real, intent(in), optional :: undef  ! ̤
   real, intent(in), optional :: undefr  ! ΰǤ̤.
         !  undefr ʤ,  undefr 
   logical, intent(in), optional :: stdopt  ! õϰϤĤʤݤɸϤɽʤ褦ˤ.
@@ -942,7 +991,7 @@ subroutine auto_interpolation_2d( x, y, r, q, u, v, undef, undefr, stdopt )
   if(present(undef))then
      defun=undef
   else
-     defun=-2147483648
+     defun=-999.0
   end if
 
   if(present(undefr))then
@@ -959,10 +1008,10 @@ subroutine auto_interpolation_2d( x, y, r, q, u, v, undef, undefr, stdopt )
 
   do j=1, nq
      do i=1, nr
-        call interpo_search_2d( x, y, r(i), q(j), ir, iq, int(defun),  &
+        call interpo_search_2d( x, y, r(i), q(j), ir, iq, undeff=0,  &
   &                             stdopt=stderr )
 
-        if(ir/=int(defun).and.iq/=int(defun))then
+        if(ir/=0.and.iq/=0)then
            if(u(ir,iq)/=rdefun)then
               if(ir<nx.and.iq<ny)then
                  if(u(ir,iq+1)/=rdefun.and.u(ir+1,iq+1)/=rdefun.and.  &
@@ -993,13 +1042,13 @@ subroutine auto_interpolation_2d( x, y, r, q, u, v, undef, undefr, stdopt )
                     v(i,j)=rdefun
                  end if
               else
-                 v(i,j)=real(defun)
+                 v(i,j)=defun
               end if
            else
               v(i,j)=rdefun
            end if
         else
-           v(i,j)=real(defun)
+           v(i,j)=defun
         end if
      end do
   end do
@@ -1021,7 +1070,7 @@ subroutine auto_interpolation_3d( x, y, z, r, q, p, u, v, undef, undefr, stdopt
   real, intent(in) :: p(:)  ! ޺ɸ 3
   real, intent(in) :: u(size(x),size(y),size(z))  ! ǡ
   real, intent(inout) :: v(size(r),size(q),size(p))  ! ޤǡ
-  integer, intent(in), optional :: undef  ! ̤
+  real, intent(in), optional :: undef  ! ̤
   real, intent(in), optional :: undefr  ! ΰǤ̤.
         !  undefr ʤ,  undefr 
   logical, intent(in), optional :: stdopt  ! õϰϤĤʤݤɸϤɽʤ褦ˤ.
@@ -1040,7 +1089,7 @@ subroutine auto_interpolation_3d( x, y, z, r, q, p, u, v, undef, undefr, stdopt
   if(present(undef))then
      defun=undef
   else
-     defun=-2147483648
+     defun=-999.0
   end if
 
   if(present(undefr))then
@@ -1061,7 +1110,7 @@ subroutine auto_interpolation_3d( x, y, z, r, q, p, u, v, undef, undefr, stdopt
            call interpo_search_3d( x, y, z, r(i), q(j), p(k),  &
   &                                ir, iq, ip, int(defun), stdopt=stderr )
 
-           if(ir/=int(defun).and.iq/=int(defun).and.ip/=int(defun))then
+           if(ir/=0.and.iq/=0.and.ip/=0)then
               if(u(ir,iq,ip)/=rdefun)then
                  if(ir<nx.and.iq<ny.and.ip<nz)then
                     if(u(ir+1,iq,ip)/=rdefun.and.  &
@@ -1139,13 +1188,13 @@ subroutine auto_interpolation_3d( x, y, z, r, q, p, u, v, undef, undefr, stdopt
                     end if
 
                  else
-                    v(i,j,k)=real(defun)
+                    v(i,j,k)=defun
                  end if
               else
                  v(i,j,k)=rdefun
               end if
            else
-              v(i,j,k)=real(defun)
+              v(i,j,k)=defun
            end if
         end do
      end do
