@@ -1039,6 +1039,7 @@ real function qrsg_2_dbz( rho, qr, qs, qg, dl )
 ! Ȥɽ. , $\lambda _x$γʬۤηǤ.
 ! ѴȤƤ, Murakami (1990)  (54) ѤƷ׻Ԥ.
   use Math_Const
+  use Cloud_Const
   use Special_Function
   implicit none
   real, intent(in) :: rho  ! 絤̩ [kg/m^3]
@@ -1046,16 +1047,6 @@ real function qrsg_2_dbz( rho, qr, qs, qg, dl )
   real, intent(in), optional :: qs  ! κ [kg/kg]
   real, intent(in), optional :: qg  ! Ǥκ [kg/kg]
   integer, intent(in), optional :: dl  ! ǥХå٥
-  real, parameter :: nr0=8.0e6  !  y ǻ [1/m^4]
-  real, parameter :: ns0=1.8e6  !  y ǻ [1/m^4]
-  real, parameter :: ng0=1.1e6  ! Ǥ y ǻ [1/m^4]
-                                ! y ǻ٤ CReSS ͤѤ.
-  real, parameter :: rhos=84.0  ! ̩ [kg/m^3]
-  real, parameter :: rhog=300.0  ! Ǥ̩ [kg/m^3]
-                                ! ǤϷ뾽¤ư뤬, Ǥϰͤ
-                                ! ꤷ, CReSS ͤѤ.
-  real, parameter :: epi=4.2  ! ɹͶΨ
-  real, parameter :: epw=80.0 ! ͶΨ
   real :: coef
   real :: z_tmp
 
