@@ -173,17 +173,22 @@ real function lamx( types, qx, rhob, Nx )
   real :: tmpa
 
   if(qx>=qthres)then
-     if(present(Nx))then
+     if(present(Nx).and.types(1:1)/='r')then  ! 'r'  Nx ȤʤΤ, ʬʤ.
         tmpa=pi*Nx/rhob/qx
-        select case (types(1:1))  ! 'r'  Nx ȤʤΤ, ʬʤ.
+        select case (types(1:1))
         case ('s')
            lamx=exp((1.0/3.0)*log(tmpa*rhos))
         case ('g')
            lamx=exp((1.0/3.0)*log(tmpa*rhog))
+        case('r')
+           write(*,*) "*** ERROR (lamx) *** :"
+           write(*,*) "type = 'r' => Disable using optional ARG."
+           write(*,*) "STOP"
+           stop
         end select
      else
         tmpa=pi/rhob/qx
-        select case (types(1:1))  ! 'r'  Nx ȤʤΤ, ʬʤ.
+        select case (types(1:1))
         case ('r')
            lamx=exp(0.25*log(tmpa*rhow*nr0))
         case ('s')
@@ -211,19 +216,24 @@ real function nx0( types, qx, rhob, Nx )
   real, intent(in) :: qx     ! ŷʪκ [kg/kg]
   real, intent(in) :: rhob   ! ܾ̩ [kg/m3]
   real, intent(in), optional :: Nx  ! qx Ȥŷʪοǻ
-  real :: tmpa, lamdax
+  real :: tmpa
 
   if(qx>=qthres)then
-     if(present(Nx))then
+     if(present(Nx).and.types(1:1)/='r')then  ! 'r'  Nx ȤʤΤ, ʬʤ.
         tmpa=pi*Nx/rhob/qx
-        select case (types(1:1))  ! 'r'  Nx ȤʤΤ, ʬʤ.
+        select case (types(1:1))
         case ('s')
-           lamdax=exp(log(Nx)+(1.0/3.0)*log(tmpa*rhos))
+           nx0=exp(log(Nx)+(1.0/3.0)*log(tmpa*rhos))
         case ('g')
-           lamdax=exp(log(Nx)+(1.0/3.0)*log(tmpa*rhog))
+           nx0=exp(log(Nx)+(1.0/3.0)*log(tmpa*rhog))
+        case('r')
+           write(*,*) "*** ERROR (nx0) *** :"
+           write(*,*) "type = 'r' => Disable using optional ARG."
+           write(*,*) "STOP"
+           stop
         end select
      else
-        select case (types(1:1))  ! 'r'  Nx ȤʤΤ, ʬʤ.
+        select case (types(1:1))
         case ('r')
            nx0=nr0
         case ('s')
@@ -864,7 +874,7 @@ real function UhxN( types, qx, rhob, rho0, Nx )
 end function UhxN
 
 
-subroutine Moist_Sature_Adjust( pres, pt, qv, qc, err )
+subroutine Moist_Sature_Adjust( pres, pt, qv, qc, err, ln )
   use Thermo_Const
   implicit none
   real, intent(in) :: pres !  [Pa]
@@ -872,8 +882,12 @@ subroutine Moist_Sature_Adjust( pres, pt, qv, qc, err )
   real, intent(inout) :: qv   !  [kg kg-1]
   real, intent(inout) :: qc   ! 庮 [kg kg-1]
   real, intent(in), optional :: err  ! convergence limit [default = 1.0e-8]
-  real :: tmppt, tmpqv, tmpqc, dqc, temp, gam, coe, pt1, qv1, qc1, err_max
+  integer, intent(in), optional :: ln  ! 롼ײ
+                                       ! 줬ꤵ줿, иˤ
+                                       ! 롼ǤڤȽǤϹԤʤ.
+  real :: tmppt, tmpqv, tmpqc, dqc, temp, gam, gam1, coe, pt1, qv1, qc1, err_max
   real :: tmp_err
+  integer :: cn
 
   call ptcheck( thetaP_2_T( pt, pres ), 'Moist Sature Adjust' )
 
@@ -892,35 +906,59 @@ subroutine Moist_Sature_Adjust( pres, pt, qv, qc, err )
   temp=thetaP_2_T( pt, pres )
   dqc=qv-qvss( temp, pres )
   gam=Lv( temp )/(Cpd*exner_func_dry( pres ))
+  gam1=Lv( temp )/Cpd
   pt1=pt
   qv1=qv
   qc1=qc
 
+  if(present(ln))then
 
-  do while (dqc>0.0.or.qc>0.0)
-     coe=qvss( temp, pres )*  &
-  &      (Cpd/(pt1*Rd)+17.269*(t0-35.86)/(exner_func_dry( pres )*(temp-t0)**2))
-     tmppt=pt1+gam*(dqc)/(1.0+gam*coe)
-     tmpqv=qv1+(pt1-tmppt)/gam
-     tmpqc=qv1+qc1-tmpqv
-     if(tmpqc>0.0)then
-        pt1=tmppt
-        qv1=tmpqv
-        qc1=tmpqc
-     else if(tmpqc<=0.0)then
-        pt1=pt1-gam*qc1
-        qv1=qv1+qc1
-        qc1=0.0
-        exit
-     end if
-     temp=thetaP_2_T( pt1, pres )
-     dqc=qv1-qvss( temp, pres )
+     do cn=1,ln
+        if(dqc>0.0.or.qc1>0.0)then
+           coe=qvss( temp, pres )*17.269*(t0-35.86)/((temp-35.86)**2)
+           tmppt=pt1+gam*(dqc)/(1.0+gam1*coe)
+           tmpqv=qv1+(pt1-tmppt)/gam
+           tmpqc=qv1+qc1-tmpqv
+           if(tmpqc>0.0)then
+              pt1=tmppt
+              qv1=tmpqv
+              qc1=tmpqc
+           else if(tmpqc<=0.0)then
+              pt1=pt1-gam*qc1
+              qv1=qv1+qc1
+              qc1=0.0
+           end if
+           temp=thetaP_2_T( pt1, pres )
+           dqc=qv1-qvss( temp, pres )
+        end if
+     end do
 
-     tmp_err=abs(tmppt-pt1)
-     if(err_max>tmp_err)then
-        exit
-     end if
-  end do
+  else
+
+     do while (dqc>0.0.or.qc1>0.0)
+        coe=qvss( temp, pres )*17.269*(t0-35.86)/((temp-35.86)**2)
+        tmppt=pt1+gam*(dqc)/(1.0+gam1*coe)
+        tmpqv=qv1+(pt1-tmppt)/gam
+        tmpqc=qv1+qc1-tmpqv
+        if(tmpqc>0.0)then
+           pt1=tmppt
+           qv1=tmpqv
+           qc1=tmpqc
+        else if(tmpqc<=0.0)then
+           pt1=pt1-gam*qc1
+           qv1=qv1+qc1
+           qc1=0.0
+        end if
+        temp=thetaP_2_T( pt1, pres )
+        dqc=qv1-qvss( temp, pres )
+
+        tmp_err=abs(tmppt-pt1)
+        if(err_max>tmp_err)then
+           exit
+        end if
+     end do
+
+  end if
 
   pt=pt1
   qv=qv1
@@ -930,7 +968,7 @@ subroutine Moist_Sature_Adjust( pres, pt, qv, qc, err )
 end subroutine Moist_Sature_Adjust
 
 
-subroutine Moist_Sature_Adjust_Ice( pres, pt, qv, qi, err )
+subroutine Moist_Sature_Adjust_Ice( pres, pt, qv, qi, err, ln )
   use Thermo_Const
   implicit none
   real, intent(in) :: pres !  [Pa]
@@ -938,8 +976,12 @@ subroutine Moist_Sature_Adjust_Ice( pres, pt, qv, qi, err )
   real, intent(inout) :: qv   !  [kg kg-1]
   real, intent(inout) :: qi   ! ɹ [kg kg-1]
   real, intent(in), optional :: err  ! convergence limit [default = 1.0e-8]
-  real :: tmppt, tmpqv, tmpqi, dqi, temp, gam, coe, pt1, qv1, qi1, err_max
+  integer, intent(in), optional :: ln  ! 롼ײ
+                                       ! 줬ꤵ줿, иˤ
+                                       ! 롼ǤڤȽǤϹԤʤ.
+  real :: tmppt, tmpqv, tmpqi, dqi, temp, gam, gam1, coe, pt1, qv1, qi1, err_max
   real :: tmp_err
+  integer :: cn
 
   call ptcheck( thetaP_2_T( pt, pres ), 'Moist Sature Adjust Ice' )
 
@@ -958,34 +1000,59 @@ subroutine Moist_Sature_Adjust_Ice( pres, pt, qv, qi, err )
   temp=thetaP_2_T( pt, pres )
   dqi=qv-qvsi( temp, pres )
   gam=Lf( temp )/(Cpd*exner_func_dry( pres ))
+  gam1=Lf( temp )/Cpd
   pt1=pt
   qv1=qv
   qi1=qi
 
-  do while (dqi>0.0.or.qi>0.0.or.temp<ti0)
-     coe=qvsi( temp, pres )*  &
-  &      (Cpd/(pt1*Rd)+21.875*(t0-7.86)/(exner_func_dry( pres )*(temp-t0)**2))
-     tmppt=pt1+gam*(dqi)/(1.0+gam*coe)
-     tmpqv=qv1+(pt1-tmppt)/gam
-     tmpqi=qv1+qi1-tmpqv
-     if(tmpqi>0.0)then
-        pt1=tmppt
-        qv1=tmpqv
-        qi1=tmpqi
-     else if(tmpqi<=0.0)then
-        pt1=pt1-gam*qi1
-        qv1=qv1+qi1
-        qi1=0.0
-        exit
-     end if
-     temp=thetaP_2_T( pt1, pres )
-     dqi=qv1-qvsi( temp, pres )
+  if(present(ln))then
 
-     tmp_err=abs(tmppt-pt1)
-     if(err_max>tmp_err)then
-        exit
-     end if
-  end do
+     do cn=1,ln
+        if(dqi>0.0.or.qi1>0.0.or.temp<ti0)then
+           coe=qvsi( temp, pres )*21.875*(t0-7.86)/((temp-7.86)**2)
+           tmppt=pt1+gam*(dqi)/(1.0+gam1*coe)
+           tmpqv=qv1+(pt1-tmppt)/gam
+           tmpqi=qv1+qi1-tmpqv
+           if(tmpqi>0.0)then
+              pt1=tmppt
+              qv1=tmpqv
+              qi1=tmpqi
+           else if(tmpqi<=0.0)then
+              pt1=pt1-gam*qi1
+              qv1=qv1+qi1
+              qi1=0.0
+           end if
+           temp=thetaP_2_T( pt1, pres )
+           dqi=qv1-qvsi( temp, pres )
+        end if
+     end do
+
+  else
+
+     do while (dqi>0.0.or.qi1>0.0.or.temp<ti0)
+        coe=qvsi( temp, pres )*21.875*(t0-7.86)/((temp-7.86)**2)
+        tmppt=pt1+gam*(dqi)/(1.0+gam1*coe)
+        tmpqv=qv1+(pt1-tmppt)/gam
+        tmpqi=qv1+qi1-tmpqv
+        if(tmpqi>0.0)then
+           pt1=tmppt
+           qv1=tmpqv
+           qi1=tmpqi
+        else if(tmpqi<=0.0)then
+           pt1=pt1-gam*qi1
+           qv1=qv1+qi1
+           qi1=0.0
+        end if
+        temp=thetaP_2_T( pt1, pres )
+        dqi=qv1-qvsi( temp, pres )
+
+        tmp_err=abs(tmppt-pt1)
+        if(err_max>tmp_err)then
+           exit
+        end if
+     end do
+
+  end if
 
   pt=pt1
   qv=qv1
