@@ -14,9 +14,13 @@ module Matrix_Calc
   public :: SOR_Jacobi_algebra
   public :: gausss
   public :: schumit_norm
+  public :: mat_dot
+  public :: Householder
+  public :: QR_method
   private :: errata
   private :: Pivot_part
   private :: vec_dot
+  private :: sum_sq
 
 
 interface trans_mat
@@ -111,6 +115,36 @@ end function
 !-----------------------------------------------------------------
 !-----------------------------------------------------------------
 
+subroutine mat_dot( a, b, c )
+! ƱΤѤ׻ (a * b = c).
+  implicit none
+  real, dimension(:,:), intent(in) :: a, b
+  real, dimension(:,:), intent(inout) :: c
+  integer :: i, j, k, l, m, n
+
+  m=size(a,1)
+  n=size(a,2)
+
+  if(n/=size(b,1).or.m/=size(b,2).or.m/=size(c,1).or.m/=size(c,2))then
+     write(*,*) "ERROR (mat_dot) : when a * b = c, a=mxn -> b=nxm, c=mxm"
+     write(*,*) "STOP."
+     stop
+  end if
+
+  do j=1,m
+     do i=1,m
+        c(i,j)=0.0
+        do k=1,n
+           c(i,j)=c(i,j)+a(i,k)*b(k,j)
+        end do
+     end do
+  end do
+
+end subroutine mat_dot
+
+!-----------------------------------------------------------------
+!-----------------------------------------------------------------
+
 subroutine invert_mat( ax, xx )
 ! ξõˡĥ, չ׻.
 ! Ūˤ, դ b ñ̥٥ȥ 1 Ĥ,õ̤Υ٥ȥ¤٤
@@ -415,7 +449,6 @@ subroutine Gau_Sei(a, b, eps, x)
      xn=(b(i)-xn)/a(i,i)
 
      err=errata(x(i),xn,1)
-write(*,*) "err_max", x(i), nx, err_max,err
 
      if(err_max<=err)then
         err_max=err
@@ -488,7 +521,6 @@ subroutine Jacobi_algebra(a, b, eps, x)
      y(i)=(b(i)-y(i))/a(i,i)
 
      err=errata(x(i),y(i),1)
-write(*,*) "err_max", x(i), nx, err_max,err
 
      if(err_max<=err)then
         err_max=err
@@ -572,7 +604,6 @@ subroutine SOR_Gau_Sei(a, b, eps, accel, x)
      xn=x(i)+accel*(xn-x(i))
 
      err=errata(x(i),xn,1)
-write(*,*) "err_max", x(i), nx, err_max,err
 
      if(err_max<=err)then
         err_max=err
@@ -655,7 +686,6 @@ subroutine SOR_Jacobi_algebra(a, b, eps, accel, x)
      y(i)=(b(i)-y(i))/a(i,i)
 
      err=errata(x(i),y(i),1)
-write(*,*) "err_max", x(i), nx, err_max,err
 
      if(err_max<=err)then
         err_max=err
@@ -858,48 +888,333 @@ end subroutine Jacobi_eigen
 !-----------------------------------------
 !-----------------------------------------
 
-!-- ʲ, ȯ !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-subroutine QR_dev( a, lambda, eps, method )
+subroutine QR_method( a, lambda, p, eps, sym_opt )
 ! QR ʬˡѤƹ a ͭͤ׻롼.
+! ʸ (2007) 4.8.
+! ʲ줿ͭ٥ȥ褦ˤƤ뤬, ͤΤɤ̤ǧ.
+! ͭͤ˴ؤƤ꤫ǧѤ.
+! ׻ȤƤ,
+! 1. Householder Ѵ
+! 2. ľη׻
+! 3. QR ʬ
+! 4. QR 
   implicit none
   real, intent(in) :: a(:,:)  ! ͭͤ [ 1 Ǥ]
   real, intent(inout) :: lambda(size(a,1))  ! a θͭ
-  real, intent(in), optional :: eps  ! ȿˡμ«
-  character(1), intent(in), optional :: method  ! a оιоι󤫤Υե饰
-                ! ǥեȤоι.
-                ! 'S' : оι -> гѲԤ,
-                ! 'A' : оι -> Householder ѴԤ.
-  integer :: i, j, n
-  real, dimension(size(a,1),size(a,2)) :: tmp_a, new_a
+  real, intent(inout), optional :: p(size(a,1),size(a,2))  ! ͭ٥ȥ.
+                       ! ֤ˤ, Householder Ѵν֤٤ʤ.
+  real, intent(in), optional :: eps  ! ȿˡμ« default = 1.0e-5
+  logical, intent(in), optional :: sym_opt  ! a оι.
+                              ! .true. = оι, default = .false.
+  integer :: i, j, k, n, counter
+  real :: dia, s, t, err, err_max, tmp1, tmp2, mu
+  real, dimension(size(a,1),size(a,2)) :: a0, q, r, b, tmp_p, tmp_pp
+  logical :: sym_link, pconv_flag
 
   n=size(a,1)
 
-!-- intent(in) 񤭴ʤΤ, ֤.
-  do j=1,n
-     do i=1,n
-        tmp_a(i,j)=a(i,j)
-        new_a(i,j)=a(i,j)
-     end do
-  end do
-
-!-- ʲ, Ѵ.
-  if(present(method))then
-     if(method=='S')then   ! гѲ.
-     else   ! Householder Ѵ.
-     end if
-  else  ! Householder Ѵ.
-     
+  if(present(sym_opt))then
+     sym_link=sym_opt
+  else
+     sym_link=.false.
   end if
 
+  if(present(p))then
+     pconv_flag=.true.
+     p=0.0
+  else
+     pconv_flag=.false.
+  end if
+
+  if(present(eps))then
+     err_max=eps
+  else
+     err_max=1.0e-5
+  end if
+
+!-- 1. Householder Ѵ.
+  if(pconv_flag.eqv..true.)then
+     call Householder( a, a0, p=tmp_p, sym_opt=sym_link )
+  else
+     call Householder( a, a0, sym_opt=sym_link )
+  end if
+
+  counter=n
+
+  do while(counter>1)
+     err=err_max
+     do while(err_max<=err)
+        q=0.0   ! QR ʬ Q_k 
+
+        do k=1,n
+           q(k,k)=1.0    ! ǽñ̹Ȥƽ
+        end do
+
+        mu=a0(counter,counter)
+        a0(counter,counter)=0.0
+        do k=1,counter-1
+           a0(k,k)=a0(k,k)-mu    ! moving original point
+        end do
+
 !-- QR ʬԤ.
-  do j=1,n
-     do i=1,n
+        do k=1,counter-1
+           dia=sqrt(abs(a0(k,k))**2+abs(a0(k+1,k))**2)
+           s=a0(k+1,k)/dia
+           t=a0(k+1,k)/(dia+a0(k,k))
+
+           a0(k+1,k)=0.0
+           a0(k,k)=dia
+
+           do j=k+1,counter
+              tmp1=a0(k,j)
+              tmp2=a0(k+1,j)
+              a0(k,j)=tmp1+s*(tmp2-t*tmp1)
+              a0(k+1,j)=tmp2-s*(tmp1+t*tmp2)
+           end do
+
+           do i=1,counter
+              tmp1=q(i,k)
+              tmp2=q(i,k+1)
+              q(i,k)=tmp1+s*(tmp2-t*tmp1)
+              q(i,k+1)=tmp2-s*(tmp1+t*tmp2)
+           end do
+        end do
+
+        do j=1,counter
+           do i=1,counter
+              r(i,j)=a0(i,j)     ! QR ʬ줿廰ѹ R
+           end do
+        end do
+
+!-- QR εѤ׻. A=RQ , R Ͼ廰, Q ϥإå٥륰ʤΤ,
+!-- a_{i,j} = R_{i,k} * Q_{k,j} + R_{i,k+1} * Q_{k+1,j}, (k=i)
+!-- , Q ž֤Ƿ׻Τ, Q=qT Ȥ, Q_{k,j} = q_{j,k}.
+!-- a_{i,j} = R_{i,k} * q_{j,k} + R_{i,k+1} * q_{j,k+1}, (k=i)
+
+        call mat_dot( r, q, a0 )
+
+!-- mooving grid
+        do i=1,counter
+           a0(i,i)=a0(i,i)+mu
+        end do
+
+!-- «Ƚ
+        if(abs(err_max)>abs(a0(counter,counter-1)))then
+           err=abs(a0(counter,counter-1))
+        end if
+
+        if(pconv_flag.eqv..true.)then
+           call mat_dot( q, tmp_p, tmp_pp )
+           tmp_p(1:n,1:n)=tmp_pp(1:n,1:n)
+        end if
+
      end do
+
+     lambda(counter)=a0(counter,counter)
+     counter=counter-1
+
   end do
 
+  if(pconv_flag.eqv..true.)then
+     p(1:n,1:n)=tmp_p(1:n,1:n)
+  end if
 
+  lambda(1)=a0(1,1)
 
-end subroutine QR_dev
+end subroutine QR_method
+
+!-----------------------------------------
+!-----------------------------------------
+
+subroutine Householder( a, b, p, sym_opt )
+! ϥۥѴѤ, Ǥռоιإå٥륰Ѵ.
+! , Υ롼ǤϷ׻®٤θ, гѤξ廰ʬϷ׻ʤ.
+! оιξ, 廰ʬϲʬƱˤʤΤ,
+! 廰ʬͤ, b βʬФ褤.
+! ͤ (2007)  4.5.2.
+  implicit none
+  real, intent(in) :: a(:,:)   ! Ǥդμоι
+  real, intent(inout) :: b(size(a,1),size(a,2))  ! إå٥륰
+  real, intent(inout), optional :: p(size(a,1),size(a,2))  ! ѴѤľ
+                                   ! ֤, Ѥ˷׻ԤΤ,
+                                   ! ׻֤٤ʤ뤳Ȥ.
+  logical, intent(in), optional :: sym_opt   ! a оι󤫤ɤ.
+                       ! default = .false. (оΤǤϤʤ)
+                       ! .true. ξ, b оʬ򤽤Τޤ֤.
+                       ! ׻®٤θ̾оʬ׻ʤ.
+  integer :: i, j, k, n
+  real :: coe, s, t, tmp
+  real, allocatable, dimension(:) :: w, pconv, qconv
+  real, dimension(size(a,1),size(a,2)) :: tmp_p, tmp_pp
+  logical :: sym_link, pconv_flag
+
+  n=size(a,1)
+
+  if(present(sym_opt))then
+     sym_link=sym_opt
+  else
+     sym_link=.false.
+  end if
+
+  if(present(p))then
+     pconv_flag=.true.
+     p=0.0
+  else
+     pconv_flag=.false.
+  end if
+
+  if(size(a,1)/=size(a,2))then
+     write(*,*) "*** ERROR (Householder) ***"
+     write(*,*) "Input array must be square matrix. STOP."
+     stop
+  end if
+
+  b(:,:)=a(:,:)
+
+  allocate(w(n))
+  allocate(pconv(n))
+  allocate(qconv(n))
+
+  if(sym_link.eqv..true.)then
+     do j=1,n-2
+        pconv=0.0
+        qconv=0.0
+        w=0.0
+        tmp_p=0.0
+     !-- Ѵκ
+        t=sum_sq( b(j+1:n,j) )
+        if(b(j+1,j)>0.0)then
+           s=sqrt(t)
+        else
+           s=-sqrt(t)
+        end if
+
+        w(1:j)=0.0
+        w(j+1)=b(j+1,j)+s
+        coe=1.0/(t+b(j+1,j)*s)   ! η (2007)  c ǤϤʤ, 2c Ǥ.
+        w(j+2:n)=b(j+2:n,j)
+
+        do k=j+1,n
+           do i=j+1,n
+              pconv(k)=pconv(k)+b(k,i)*w(i)
+           end do
+           pconv(k)=coe*pconv(k)
+        end do
+
+        do k=j+1,n
+           do i=j+1,n
+              qconv(k)=qconv(k)+pconv(i)*w(i)
+           end do
+           qconv(k)=pconv(k)-0.5*coe*qconv(k)*w(k)
+        end do
+
+     !-- ѴˤѴ
+
+        b(j+1,j)=-s
+        b(j+2:n,j)=0.0
+
+        do k=j+1,n
+           do i=j+1,n
+              b(i,k)=b(i,k)-qconv(i)*w(k)-w(i)*qconv(k)
+           end do
+        end do
+
+        if(pconv_flag.eqv..true.)then
+           do k=j+1,n   ! w  j+1 ʾʬΤ󥼥.
+              do i=j+1,n
+                 tmp_p(i,k)=-coe*w(i)*w(k)
+              end do
+           end do
+           do k=1,n
+              tmp_p(k,k)=1.0+tmp_p(k,k)
+           end do
+
+           if(j==1)then
+              p(1:n,1:n)=tmp_p(1:n,1:n)
+           else
+              call mat_dot( p, tmp_p, tmp_pp )
+              p(1:n,1:n)=tmp_pp(1:n,1:n)
+           end if
+
+        end if
+
+     end do
+
+     do k=1,n
+        do j=k,n
+           b(k,j)=b(j,k)
+        end do
+     end do
+
+  else   ! оιξ (ޤбƤʤ.)
+
+     do j=1,n-2
+        pconv=0.0
+        qconv=0.0
+        w=0.0
+        tmp_p=0.0
+     !-- Ѵκ
+        t=sum_sq( b(j+1:n,j) )
+        if(b(j+1,j)>0.0)then
+           s=sqrt(t)
+        else
+           s=-sqrt(t)
+        end if
+
+        w(1:j)=0.0
+        w(j+1)=b(j+1,j)+s
+        coe=1.0/(t+b(j+1,j)*s)   ! η (2007)  c ǤϤʤ, 2c Ǥ.
+        w(j+2:n)=b(j+2:n,j)
+
+        do k=j+1,n
+           do i=j+1,n
+              pconv(k)=pconv(k)+b(k,i)*w(i)
+           end do
+           pconv(k)=coe*pconv(k)
+        end do
+
+        do k=j+1,n
+           do i=j+1,n
+              qconv(k)=qconv(k)+pconv(i)*w(i)
+           end do
+           qconv(k)=pconv(k)-0.5*coe*qconv(k)*w(k)
+        end do
+
+     !-- ѴˤѴ
+
+        b(j+1,j)=-s
+        b(j+2:n,j)=0.0
+
+        do k=j+1,n
+           do i=j+1,n
+              b(i,k)=b(i,k)-qconv(i)*w(k)-w(i)*qconv(k)
+           end do
+        end do
+
+        if(pconv_flag.eqv..true.)then
+           do k=j+1,n   ! w  j+1 ʾʬΤ󥼥.
+              do i=j+1,n
+                 tmp_p(i,k)=-coe*w(i)*w(k)
+              end do
+           end do
+           do k=1,n
+              tmp_p(k,k)=1.0+tmp_p(k,k)
+           end do
+
+           if(j==1)then
+              p(1:n,1:n)=tmp_p(1:n,1:n)
+           else
+              call mat_dot( p, tmp_p, tmp_pp )
+              p(1:n,1:n)=tmp_pp(1:n,1:n)
+           end if
+
+        end if
+
+     end do
+
+  end if
+
+end subroutine Householder
 
 !-----------------------------------------
 !-----------------------------------------
@@ -909,6 +1224,8 @@ subroutine schumit_norm( u, v )
 !  1 Ǥ٥ȥγʬ,  2 ʬ٥ȥ뷲 1 ٥ȥɽ.
 ! Ĥޤ, u(i,j)  j ܥ٥ȥ i ʬȤȤɽ.
 ! ɽʤ, ĥ٥ȥ򲣤¤٤.
+! ܥ롼ϥߥåȤľ򲽤ܤ˷׻ƤΤ,
+! ׻®٤Ū٤餷.
   implicit none
   real, intent(in) :: u(:,:)  ! ľ򲽤Υ٥ȥ
   real, intent(inout) :: v(size(u,1),size(u,2))  ! ľ򲽸Υ٥ȥ
@@ -1050,12 +1367,27 @@ real function vec_dot( u, v )
   return
 end function
 
-
-
-!-----------------------------------------
 !-----------------------------------------
 
-!-----------------------------------------
+real function sum_sq( a )
+! Ǥդ 1 Ǥγʬ 2 ¤׻.
+  implicit none
+  real, intent(in) :: a(:)
+  integer :: i, n
+  real :: tmp
+
+  n=size(a)
+  tmp=0.0
+
+  do i=1,n
+     tmp=tmp+a(i)**2
+  end do
+
+  sum_sq=tmp
+
+  return
+end function sum_sq
+
 !-----------------------------------------
 
 end module Matrix_Calc
