@@ -1260,10 +1260,12 @@ subroutine hydro_grad_eqb( r, z, coril, v, pres_s, rho_s, pres, rho, error, dl )
   real, intent(inout) :: pres(size(r),size(z))  ! ʿվε [Pa]
   real, intent(inout) :: rho(size(r),size(z))  ! ʿվ̩ [kg/m^3]
   integer, intent(in), optional :: dl  ! ǥХå٥
+  real :: dr(size(r)), dz(size(z))
   real :: old_pres(size(r),size(z)), old_rho(size(r),size(z))
+  real :: N2(size(r),size(z)), tmprho(size(r),size(z)), force(size(r),size(z))
   integer :: nr, nz
   integer :: i, j
-  real :: err, err_tmp, err_max
+  real :: err, err_tmp, err_max, tmpp, tmpc, tmpr
 
   nr=size(r)
   nz=size(z)
@@ -1277,45 +1279,81 @@ subroutine hydro_grad_eqb( r, z, coril, v, pres_s, rho_s, pres, rho, error, dl )
 !-- ʲǳƹ٤ˤ, ̩٤ϰǤȤƷʿդ鵤׻,
 !-- ͤѤϳʿդ̩٤. eps ʲˤʤޤǷ֤.
 !--  2 ȥǥ󥰤.
-  do i=1,nz
-     old_pres(nr,i)=pres_s(i)
+  do j=1,nz
+     do i=1,nr
+        old_pres(i,j)=pres_s(j)
+     end do
   end do
 !-- ̩٤ˤĤƤ, ʿ̰ͤ
   do j=1,nz
      do i=1,nr
-        old_rho(i,j)=rho_s(j)
+        old_rho(i,j)=log(rho_s(j))
      end do
   end do
 
+  do i=1,nr-1
+     dr(i)=r(i+1)-r(i)
+  end do
+  do j=1,nz-1
+     dz(j)=z(j+1)-z(j)
+  end do
+
 !-- ʲǥ졼󳫻.
   err=err_max
 
   do while(err>=err_max)
      err=0.0
-!-- ʿդ鰵Ͼ׻
+
 !$omp parallel default(shared)
-!$omp do schedule(dynamic) private(j)
+!$omp do schedule(dynamic) private(i,j)
+
      do j=1,nz
-        call grad_wind_pres( r, coril(:,j), v(:,j), old_rho(:,j), r(nr), old_pres(nr,j), pres(:,j) )
+        do i=1,nr
+           if(r(i)/=0.0)then
+              force(i,j)=coril(i,j)*v(i,j)+v(i,j)*v(i,j)/r(i)
+           else
+              force(i,j)=0.0
+           end if
+        end do
      end do
+
 !$omp end do
 !$omp end parallel
 
-!-- ϳʿդ̩پ
-     do i=1,nr
-        call grad_1d( z, pres(i,:), rho(i,:) )
-        do j=1,nz
-           rho(i,j)=-rho(i,j)/g  ! ϳؤμ, dp/dz=-g*rho ǤΤ
+!$omp parallel default(shared)
+!$omp do schedule(runtime) private(i,j,tmpp,tmpc,tmpr)
+
+     do j=1,nz-1
+        do i=1,nr-1
+           tmpp=old_pres(i+1,j)*dz(j)+force(i,j)*dr(i)*old_pres(i,j+1)/g
+           tmpc=dz(j)+dr(i)*force(i,j)/g
+           tmpr=old_rho(i+1,j)*dz(j)+force(i,j)*dr(i)*old_rho(i,j+1)/g  &
+  &             +(force(i,j+1)-force(i,j))*dr(i)/g
+           pres(i,j)=tmpp/tmpc
+           tmprho(i,j)=tmpr/tmpc
         end do
      end do
 
+!$omp end do
+!$omp end parallel
+
+!-- ͤ
+     do i=1,nr
+        pres(i,nz)=pres_s(nz)
+        tmprho(i,nz)=log(rho_s(nz))
+     end do
+     do j=1,nz
+        pres(nr,j)=pres_s(j)
+        tmprho(nr,j)=log(rho_s(j))
+     end do
+
 !-- ̩پμ«׻
      do j=1,nz
         do i=1,nr
-           if(rho(i,j)==0.0)then
-              err_tmp=abs(old_rho(i,j)-rho(i,j))/abs(old_rho(i,j))
+           if(tmprho(i,j)==0.0)then
+              err_tmp=abs(exp(old_rho(i,j))-exp(tmprho(i,j)))/abs(exp(old_rho(i,j)))
            else
-              err_tmp=abs(old_rho(i,j)-rho(i,j))/abs(old_rho(i,j))
+              err_tmp=abs(exp(old_rho(i,j))-exp(tmprho(i,j)))/abs(exp(tmprho(i,j)))
            end if
 
 !-- ι
@@ -1323,7 +1361,7 @@ subroutine hydro_grad_eqb( r, z, coril, v, pres_s, rho_s, pres, rho, error, dl )
               err=err_tmp
            end if
 
-           old_rho(i,j)=rho(i,j)
+           old_rho(i,j)=tmprho(i,j)
            old_pres(i,j)=pres(i,j)
 
         end do
@@ -1331,6 +1369,12 @@ subroutine hydro_grad_eqb( r, z, coril, v, pres_s, rho_s, pres, rho, error, dl )
 
   end do
 
+  do j=1,nz
+     do i=1,nr
+        rho(i,j)=exp(tmprho(i,j))
+     end do
+  end do
+
   if(present(dl))then
      do j=1,nz
         call debug_flag_r( dl, 'typhoon_analy', 'hydro_grad_eqb (pres)',  &
@@ -1371,13 +1415,11 @@ subroutine grad_wind_pres( r, coril, v, rho, r_ref, p_ref, pres )
      if(r(i)<r_ref)then
         call rectangle_int( r, grad, r(i), r_ref, pres(i) )
         pres(i)=p_ref-pres(i)
+     else if(r(i)>r_ref)then
+        call rectangle_int( r, grad, r_ref, r(i), pres(i) )
+        pres(i)=p_ref+pres(i)
      else
-        if(r(i)>r_ref)then
-           call rectangle_int( r, grad, r_ref, r(i), pres(i) )
-           pres(i)=p_ref+pres(i)
-        else
-           pres(i)=p_ref
-        end if
+        pres(i)=p_ref
      end if
   end do
 
