@@ -71,7 +71,8 @@ subroutine v1_2_v2_1d( v1, v2, val1, val2, undef, sig )
      end do
   end if
 
-  call auto_interpolation_1d( tmp1, tmp2, tmpv1, tmpv2, int(undeff) )
+  call auto_interpolation_1d( tmp1, tmp2, tmpv1, tmpv2, undef=undeff,  &
+  &                           undefr=undeff )
 
   if(vc1(1:1)=='m')then
      do i=1,n2
